@@ -119,6 +119,7 @@ Usage(int argc, char *argv[])
         M1("Usage: %s [options] file[(map)] ...\n", argv[0]);
     M("Legal options:\n");
     M("-?,-help             Print this message\n");
+    M("-version             Print the version number\n");
     if (!xkblist)
     {
         M("-a                   Show all actions\n");
@@ -252,7 +253,11 @@ parseArgs(int argc, char *argv[])
             Usage(argc, argv);
             exit(0);
         }
-        else if ((strcmp(argv[i], "-a") == 0) && (!xkblist))
+        else if (strcmp(argv[i], "-version") == 0)
+        {
+            printf("xkbcomp %s\n", PACKAGE_VERSION);
+            exit(0);
+        } else if ((strcmp(argv[i], "-a") == 0) && (!xkblist))
         {
             showImplicit = True;
         }
@@ -648,25 +653,25 @@ parseArgs(int argc, char *argv[])
         len = strlen(inputFile);
         if (inputFile[len - 1] == ')')
         {
-            char *tmp;
-            if ((tmp = strchr(inputFile, '(')) != NULL)
+            char *tmpstr;
+            if ((tmpstr = strchr(inputFile, '(')) != NULL)
             {
-                *tmp = '\0';
+                *tmpstr = '\0';
                 inputFile[len - 1] = '\0';
-                tmp++;
-                if (*tmp == '\0')
+                tmpstr++;
+                if (*tmpstr == '\0')
                 {
                     WARN("Empty map in filename\n");
                     ACTION("Ignored\n");
                 }
                 else if (inputMap == NULL)
                 {
-                    inputMap = uStringDup(tmp);
+                    inputMap = uStringDup(tmpstr);
                 }
                 else
                 {
                     WARN("Map specified in filename and with -m flag\n");
-                    ACTION1("map from name (\"%s\") ignored\n", tmp);
+                    ACTION1("map from name (\"%s\") ignored\n", tmpstr);
                 }
             }
             else
